@@ -17,7 +17,7 @@ use List::MoreUtils qw(firstidx);
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = 'v1.6.0'; # VERSION
+our $VERSION = 'v1.6.1'; # VERSION
 
 has uri => (
     is       => 'ro',
@@ -226,7 +226,21 @@ sub _load_cfg {
 
 sub _def_user { $ENV{CLICKHOUSE_USER}     || $_[0]->_clickcnf->{user}     }
 sub _def_pass { $ENV{CLICKHOUSE_PASSWORD} || shift->_clickcnf->{password} }
-sub _dsn { shift->registry_uri->dbi_dsn }
+
+sub _dsn {
+    # Always set the host name to the default if it's not set. Otherwise
+    # URI::db::_odbc returns the DSN `dbi:ODBC:DSN=sqitch;Driver=ClickHouse`.
+    # We don't want that, because no such DSN exists. By setting the host
+    # name, it instead returns
+    # `dbi:ODBC:Server=localhost;Database=sqitch;Driver=ClickHouse`, almost
+    # certainly more correct.
+    my $uri = shift->registry_uri;
+    unless ($uri->host) {
+        $uri = $uri->clone;
+        $uri->host('localhost');
+    }
+    return $uri->dbi_dsn
+}
 
 has dbh => (
     is      => 'rw',
@@ -889,7 +903,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2025 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
